import {Component, OnInit, ViewChild} from '@angular/core';
import { NgbModalRef } from '@ng-bootstrap/ng-bootstrap';
import { JhiEventManager } from 'ng-jhipster';
import { Account, Principal } from '../shared';
import {OverAllService} from '../overAll/overAll.service';
import {WarnListComponent} from '../modal/warn-list/warn-list.component';
import {pageSize} from '../app.constants';
import {AlarmService} from '../alarm/alarm.service';
import {NzMessageService} from 'ng-zorro-antd';

@Component({
    selector: 'jhi-home',
    templateUrl: './home.component.html',
    styleUrls: [
        'home.css'
    ]

})
export class HomeComponent implements OnInit {
    @ViewChild('warnList') warnList:WarnListComponent;

    leftOneChart;
    leftTwoChart;
    rightOneChart;
    rightTwoChart;

    totalNum;
    groupList;

    pageNum = 1;
    pageCount = pageSize;
    groupid = null;
    loading = false;

    runGroupId = null;

    constructor(
        private overAllSer:OverAllService,private message:NzMessageService,
        private alarmSer:AlarmService,
        private principal: Principal,
        private eventManager: JhiEventManager
    ) {
    }

    ngOnInit() {
        this.getAlarmList();
        this.runLeft();

        this.findGroupCount();
        this.findHostCount();

        this.getGroup();
    }

    runLeft(){
        this.setLeftOne();
        this.setLeftTwo();
    }

    //获取分组
    getGroup() {
        this.overAllSer.findGroup().subscribe(
            (res) => {
                this.groupList = res.data;
            }
        );
    }

    setLeftOne(){
        this.leftOneChart =
            {
                title: {
                    text: '82台\n主机',
                    x: '23%',
                    y: '40%',
                    itemGap: 50,
                    textStyle: {
                        color: '#fff',
                        fontSize: 26,
                        fontWeight: 'normal',
                    },
                    subtextStyle: {
                        color: '#de4751',
                        fontSize: 12
                    }
                },
                tooltip: {
                    trigger: 'item',
                    formatter: "{a} <br/>{b} : {c} ({d}%)"
                },

                series: [
                    {
                        name: '访问来源',
                        type: 'pie',
                        clockWise: true,
                        center: ["30%", "50%"],
                        radius: ['40%', '60%'],
                        color: ['#fcee56', '#ff8400', '#f93215', '#701002', '#2fb35b', '#a0a0a0'],
                        label: {
                            normal: {
                                show: false,
                                position: 'center'
                            }
                        },
                        labelLine: {
                            normal: {
                                show: false
                            }
                        },
                        data: [
                            {value: 235, name: '告警'},
                            {value: 110, name: '一般严重'},
                            {value: 234, name: '严重'},
                            {value: 35, name: '灾难'},
                            {value: 505, name: '正常'},
                            {value: 48, name: '未知'}
                        ],
                        itemStyle: {
                            emphasis: {
                                shadowBlur: 10,
                                shadowOffsetX: 0,
                                shadowColor: 'rgba(0, 0, 0, 0.5)'
                            }
                        }
                    }
                ]
            };
    }

    setLeftTwo(){
        this.leftTwoChart =
            {
                title: {
                    text: '82台\n主机',
                    x: '23%',
                    y: '40%',
                    itemGap: 50,
                    textStyle: {
                        color: '#fff',
                        fontSize: 26,
                        fontWeight: 'normal',
                    },
                    subtextStyle: {
                        color: '#de4751',
                        fontSize: 12
                    }
                },
                tooltip: {
                    trigger: 'item',
                    formatter: "{a} <br/>{b} : {c} ({d}%)"
                },

                series: [
                    {
                        name: '访问来源',
                        type: 'pie',
                        clockWise: true,
                        center: ["30%", "50%"],
                        radius: ['40%', '60%'],
                        color: ['#fcee56', '#ff8400', '#f93215', '#701002', '#2fb35b', '#a0a0a0'],
                        label: {
                            normal: {
                                show: false,
                                position: 'center'
                            }
                        },
                        labelLine: {
                            normal: {
                                show: false
                            }
                        },
                        data: [
                            {value: 235, name: '告警'},
                            {value: 110, name: '一般严重'},
                            {value: 234, name: '严重'},
                            {value: 35, name: '灾难'},
                            {value: 505, name: '正常'},
                            {value: 48, name: '未知'}
                        ],
                        itemStyle: {
                            emphasis: {
                                shadowBlur: 10,
                                shadowOffsetX: 0,
                                shadowColor: 'rgba(0, 0, 0, 0.5)'
                            }
                        }
                    }
                ]
            };
    }

    findGroupCount(){
        this.overAllSer.findGroupCount().subscribe(
            (res)=>{
                this.rightOneChart = {
                    tooltip : {
                        trigger: 'item',
                        formatter: "{a} <br/>{b} : {c} ({d}%)"
                    },

                    series : [
                        {
                            type: 'pie',
                            radius : '55%',
                            center: ['50%', '60%'],
                            data:res.data.map(e=>{
                                const arr = {
                                    value:e.count,
                                    name:e.name
                                };
                                return arr;
                            }),
                            itemStyle: {
                                emphasis: {
                                    shadowBlur: 10,
                                    shadowOffsetX: 0,
                                    shadowColor: 'rgba(0, 0, 0, 0.5)'
                                }
                            }
                        }
                    ]
                };
            }
        )
    }

    findHostCount(){
        this.overAllSer.findHostCount().subscribe(
            (res)=>{
                this.rightTwoChart = {
                    tooltip : {
                        trigger: 'item',
                        formatter: "{a} <br/>{b} : {c} ({d}%)"
                    },

                    series : [
                        {
                            name: '访问来源',
                            type: 'pie',
                            radius : '55%',
                            center: ['50%', '60%'],
                            data:res.data.map(e=>{
                                const arr = {
                                    value:e.count,
                                    name:e.name
                                }
                                return arr;
                            }),
                            itemStyle: {
                                emphasis: {
                                    shadowBlur: 10,
                                    shadowOffsetX: 0,
                                    shadowColor: 'rgba(0, 0, 0, 0.5)'
                                }
                            }
                        }
                    ]
                };
            }
        )
    }

    //获取告警分组
    getAlarmList(){
        const data = {
            pageNum: this.pageNum,
            pageCount: this.pageCount,
            obj:{
                groupid: this.groupid,
            }
        };
        this.alarmSer.eventFind(data).subscribe(
            (res) => {
                if(res.errCode == 10000){
                    if(res.data){
                        this.warnList = res.data.data;
                        this.totalNum = res.data.totalNum;
                    }
                }else{
                    this.message.info(res.errMsg);
                }
            }
        );
    }

    //关注资源图表
    setBarEcharts(){
        // var color= ['#fb734e', '#e32f46','#94d96c', '#0bbcb7','#1a9bfc','#7049f0'];
        // var dataStyle = {
        //     normal: {
        //         label: {
        //             show: false
        //         },
        //         labelLine: {
        //             show: false
        //         },
        //         shadowBlur: 40,
        //         borderWidth: 10,
        //         shadowColor: 'rgba(0, 0, 0, 0)' //边框阴影
        //     }
        // };
        // var placeHolderStyle = {
        //     normal: {
        //         color: '#393d50',
        //         label: {
        //             show: false
        //         },
        //         labelLine: {
        //             show: false
        //         }
        //     },
        //     emphasis: {
        //         color: '#393d50'
        //     }
        // };
        // option = {
        //     backgroundColor: '#142058',
        //     title: {
        //         text: '匹配度',
        //         x: 'center',
        //         y: 'center',
        //         textStyle: {
        //             fontWeight: 'normal',
        //             fontSize: 24,
        //             color: "#fff",
        //         }
        //     },
        //     tooltip: {
        //         trigger: 'item',
        //         show: true,
        //         formatter: "{b} : <br/>{d}%",
        //         backgroundColor: 'rgba(0,0,0,0.7)', // 背景
        //         padding: [8, 10], //内边距
        //         extraCssText: 'box-shadow: 0 0 3px rgba(255, 255, 255, 0.4);', //添加阴影
        //     },
        //
        //     series: [{
        //         name: 'Line 1',
        //         type: 'pie',
        //         clockWise: false,
        //         radius: [186, 200],
        //         center:['50%','50%'],
        //         itemStyle: dataStyle,
        //         hoverAnimation: false,
        //         startAngle: 90,
        //         label:{
        //             borderRadius:'10',
        //         },
        //         data: [{
        //             value: 54.6,
        //             name: '四级匹配度',
        //             itemStyle: {
        //                 normal: {
        //                     color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [{
        //                         offset: 0,
        //                         color:color[0]
        //                     }, {
        //                         offset: 1,
        //                         color: color[1]
        //                     }])
        //                 }
        //             }
        //         },
        //             {
        //                 value: 45.4,
        //                 name: '',
        //                 tooltip: {
        //                     show: false
        //                 },
        //                 itemStyle: placeHolderStyle
        //             },
        //         ]
        //     },
        //         {
        //             name: 'Line 2',
        //             type: 'pie',
        //             clockWise: false,
        //             radius: [146, 160],
        //             center:['50%','50%'],
        //             itemStyle: dataStyle,
        //             hoverAnimation: false,
        //             startAngle: 90,
        //             data: [{
        //                 value: 56.7,
        //                 name: '三级匹配度',
        //                 itemStyle: {
        //                     normal: {
        //                         color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [{
        //                             offset: 0,
        //                             color: color[2]
        //                         }, {
        //                             offset: 1,
        //                             color: color[3]
        //                         }])
        //                     }
        //                 }
        //             },
        //                 {
        //                     value: 43.3,
        //                     name: '',
        //                     tooltip: {
        //                         show: false
        //                     },
        //                     itemStyle: placeHolderStyle
        //                 },
        //             ]
        //         },
        //         {
        //             name: 'Line 3',
        //             type: 'pie',
        //             clockWise: false,
        //             radius: [106, 120],
        //             center:['50%','50%'],
        //             itemStyle: dataStyle,
        //             hoverAnimation: false,
        //             startAngle: 90,
        //             data: [{
        //                 value: 30,
        //                 name: '二级匹配度',
        //                 itemStyle: {
        //                     normal: {
        //                         color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [{
        //                             offset: 0,
        //                             color: color[4]
        //                         }, {
        //                             offset: 1,
        //                             color: color[5]
        //                         }]),
        //                     }
        //                 }
        //             },
        //                 {
        //                     value: 0,
        //                     name: '',
        //                     tooltip: {
        //                         show: false
        //                     },
        //                     itemStyle: placeHolderStyle
        //                 },
        //             ]
        //         }
        //     ]
        // };
    }

    change(e){
        this.pageNum = e;
        this.getAlarmList();
    }
}
